Index: trunk/src/org/openstreetmap/josm/actions/AddNodeAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/AddNodeAction.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/actions/AddNodeAction.java	(revision 6977)
@@ -23,4 +23,7 @@
     private String textLatLon, textEastNorth;
 
+    /**
+     * Constructs a new {@code AddNodeAction}.
+     */
     public AddNodeAction() {
         super(tr("Add Node..."), "addnode", tr("Add a node by entering latitude / longitude or easting / northing."),
Index: trunk/src/org/openstreetmap/josm/actions/AlignInLineAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/AlignInLineAction.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/actions/AlignInLineAction.java	(revision 6977)
@@ -257,8 +257,6 @@
             for(int i = 1; i < nodes.size()-1; i++)
                 if(nodes.get(i) == node) {
-                    System.out.printf("Find 2 neighbors\n");
                     neighbors.add(nodes.get(i-1));
                     neighbors.add(nodes.get(i+1));
-                    //lines.add(new Line(nodes.get(i-1), nodes.get(i+1)));
                 }
             if(neighbors.size() == 0)
Index: trunk/src/org/openstreetmap/josm/actions/CreateCircleAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/CreateCircleAction.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/actions/CreateCircleAction.java	(revision 6977)
@@ -97,5 +97,5 @@
      * Class designed to create a couple between a node and its angle relative to the center of the circle.
      */
-    private class PolarNode {
+    private static class PolarNode {
         double a;
         Node node;
@@ -111,5 +111,5 @@
      * Comparator used to order PolarNode relative to their angle.
      */
-    private class PolarNodeComparator implements Comparator<PolarNode> {
+    private static class PolarNodeComparator implements Comparator<PolarNode> {
 
         @Override
@@ -186,5 +186,5 @@
             double yc = 0.5 * (y1 + y2);
             center = new EastNorth(xc, yc);
-        } else if (nodes.size() == 3) {
+        } else {
             // triangle: three single nodes needed or a way with three nodes
             center = Geometry.getCenter(nodes);
Index: trunk/src/org/openstreetmap/josm/actions/JoinAreasAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/actions/JoinAreasAction.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/actions/JoinAreasAction.java	(revision 6977)
@@ -54,5 +54,5 @@
     private final LinkedList<Command> cmds = new LinkedList<Command>();
     private int cmdsCount = 0;
-    private final LinkedList<Relation> addedRelations = new LinkedList<Relation>();
+    private final List<Relation> addedRelations = new LinkedList<Relation>();
 
     /**
Index: trunk/src/org/openstreetmap/josm/gui/MapStatus.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/MapStatus.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/gui/MapStatus.java	(revision 6977)
@@ -717,5 +717,5 @@
     private class MapStatusPopupMenu extends JPopupMenu {
 
-        private final JMenuItem jumpButton = createActionComponent(Main.main.menu.jumpToAct);
+        private final JMenuItem jumpButton = add(Main.main.menu.jumpToAct);
         
         private final Collection<JCheckBoxMenuItem> somItems = new ArrayList<JCheckBoxMenuItem>();
@@ -743,5 +743,4 @@
             }
             
-            add(jumpButton);
             add(separator);
             add(doNotHide);
@@ -751,11 +750,11 @@
                 public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
                     Component invoker = ((JPopupMenu)e.getSource()).getInvoker();
-                    jumpButton.setVisible(invoker == latText || invoker == lonText);
-                    String currentSOM = ProjectionPreference.PROP_SYSTEM_OF_MEASUREMENT.get();;
+                    jumpButton.setVisible(latText.equals(invoker) || lonText.equals(invoker));
+                    String currentSOM = ProjectionPreference.PROP_SYSTEM_OF_MEASUREMENT.get();
                     for (JMenuItem item : somItems) {
                         item.setSelected(item.getText().equals(currentSOM));
-                        item.setVisible(invoker == distText);
+                        item.setVisible(distText.equals(invoker));
                     }
-                    separator.setVisible(invoker == distText);
+                    separator.setVisible(distText.equals(invoker));
                     doNotHide.setSelected(Main.pref.getBoolean("statusbar.always-visible", true));
                 }
Index: trunk/src/org/openstreetmap/josm/gui/io/UploadPrimitivesTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/io/UploadPrimitivesTask.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/gui/io/UploadPrimitivesTask.java	(revision 6977)
@@ -7,5 +7,4 @@
 import static org.openstreetmap.josm.tools.I18n.trn;
 
-import java.io.IOException;
 import java.lang.reflect.InvocationTargetException;
 import java.util.HashSet;
@@ -38,11 +37,10 @@
 import org.openstreetmap.josm.io.OsmTransferException;
 import org.openstreetmap.josm.tools.ImageProvider;
-import org.xml.sax.SAXException;
 
 /**
- * The task for uploading a collection of primitives
+ * The task for uploading a collection of primitives.
  *
  */
-public class UploadPrimitivesTask extends  AbstractUploadTask {
+public class UploadPrimitivesTask extends AbstractUploadTask {
     private boolean uploadCanceled = false;
     private Exception lastException = null;
@@ -240,5 +238,5 @@
     }
 
-    @Override protected void realRun() throws SAXException, IOException {
+    @Override protected void realRun() {
         try {
             uploadloop:while(true) {
@@ -294,9 +292,9 @@
                 }
             }
-        // if required close the changeset
-        //
-        if (strategy.isCloseChangesetAfterUpload() && changeset != null && !changeset.isNew() && changeset.isOpen()) {
-            OsmApi.getOsmApi().closeChangeset(changeset, progressMonitor.createSubTaskMonitor(0, false));
-        }
+            // if required close the changeset
+            //
+            if (strategy.isCloseChangesetAfterUpload() && changeset != null && !changeset.isNew() && changeset.isOpen()) {
+                OsmApi.getOsmApi().closeChangeset(changeset, progressMonitor.createSubTaskMonitor(0, false));
+            }
         } catch (Exception e) {
             if (uploadCanceled) {
Index: trunk/src/org/openstreetmap/josm/gui/layer/gpx/ChooseTrackVisibilityAction.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/layer/gpx/ChooseTrackVisibilityAction.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/gui/layer/gpx/ChooseTrackVisibilityAction.java	(revision 6977)
@@ -64,5 +64,5 @@
      * Class to format a length according to SystemOfMesurement.
      */
-    private final class TrackLength {
+    private static final class TrackLength {
         private double value;
 
@@ -88,5 +88,5 @@
      * Comparator for TrackLength objects
      */
-    private final class LengthContentComparator implements Comparator<TrackLength> {
+    private static final class LengthContentComparator implements Comparator<TrackLength> {
 
         /**
Index: trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/Selector.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/Selector.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/gui/mappaint/mapcss/Selector.java	(revision 6977)
@@ -265,11 +265,9 @@
                             final Node n = w.getNode(i - 1);
                             final Environment e2 = e.withPrimitive(n).withParent(w).withChild(e.osm);
-                            if (left.matches(e2)) {
-                                if (link.matches(e2.withLinkContext())) {
-                                    e.child = n;
-                                    e.index = i;
-                                    e.parent = w;
-                                    return true;
-                                }
+                            if (left.matches(e2) && link.matches(e2.withLinkContext())) {
+                                e.child = n;
+                                e.index = i;
+                                e.parent = w;
+                                return true;
                             }
                         }
Index: trunk/src/org/openstreetmap/josm/tools/PlatformHookOsx.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/PlatformHookOsx.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/tools/PlatformHookOsx.java	(revision 6977)
@@ -51,6 +51,5 @@
         String java = System.getProperty("java.version");
         String os = System.getProperty("os.version");
-        if (java != null && java.startsWith("1.6") && os != null && (
-                os.startsWith("10.7.") || os.startsWith("10.8") || os.startsWith("10.9"))) {
+        if (java != null && java.startsWith("1.6") && os != null && os.matches("^10\\.[789].*")) {
             askUpdateJava(java);
         }
Index: trunk/src/org/openstreetmap/josm/tools/PlatformHookUnixoid.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/PlatformHookUnixoid.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/tools/PlatformHookUnixoid.java	(revision 6977)
@@ -46,6 +46,5 @@
             String os = getOSDescription();
             if (java != null && java.startsWith("1.6") && os != null && (
-                    os.startsWith("Linux Debian GNU/Linux 7") || os.startsWith("Linux Mint") ||
-                    os.startsWith("Linux Ubuntu 12") || os.startsWith("Linux Ubuntu 13") || os.startsWith("Linux Ubuntu 14"))) {
+                    os.startsWith("Linux Debian GNU/Linux 7") || os.startsWith("Linux Mint") || os.matches("^Linux Ubuntu 1[234].*"))) {
                 String url;
                 // apturl does not exist on Debian (see #8465)
Index: trunk/src/org/openstreetmap/josm/tools/Utils.java
===================================================================
--- trunk/src/org/openstreetmap/josm/tools/Utils.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/tools/Utils.java	(revision 6977)
@@ -75,5 +75,5 @@
     private static final int MILLIS_OF_DAY = 86400000;
 
-    public static String URL_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-._~:/?#[]@!$&'()*+,;=";
+    public static final String URL_CHARS = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-._~:/?#[]@!$&'()*+,;=";
     
     /**

Index: trunk/src/org/openstreetmap/josm/gui/io/DownloadPrimitivesWithReferrersTask.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/io/DownloadPrimitivesWithReferrersTask.java	(revision 6976)
+++ trunk/src/org/openstreetmap/josm/gui/io/DownloadPrimitivesWithReferrersTask.java	(revision 6977)
@@ -75,5 +75,4 @@
         // All downloaded primitives are put in a tmpLayer
         tmpLayer = new OsmDataLayer(new DataSet(), OsmDataLayer.createNewName(), null);
-        //Main.main.addLayer(tmpLayer);
     }
 
@@ -194,16 +193,16 @@
      * Dialog for report a problem during download.
      * @param errs Primitives involved
      * @param TITLE Title of dialog
      * @param TEXT Detail message
      * @param LIST_LABEL List of primitives description
      * @param msgType Type of message {@see JOptionPane}
      * @return The Dialog object
      */
     private static ExtendedDialog reportProblemDialog(Set<PrimitiveId> errs,
-            String TITLE, String TEXT, String LIST_LABEL, int msgType) {
+            String title, String text, String listLabel, int msgType) {
         JPanel p = new JPanel(new GridBagLayout());
-        p.add(new HtmlPanel(TEXT), GBC.eop());
-        if (LIST_LABEL != null) {
-            JLabel missing = new JLabel(LIST_LABEL);
+        p.add(new HtmlPanel(text), GBC.eop());
+        if (listLabel != null) {
+            JLabel missing = new JLabel(listLabel);
             missing.setFont(missing.getFont().deriveFont(Font.PLAIN));
             p.add(missing, GBC.eol());
@@ -221,5 +220,5 @@
         return new ExtendedDialog(
                 Main.parent,
-                TITLE,
+                title,
                 new String[] { tr("Ok") })
         .setButtonIcons(new String[] { "ok" })
@@ -194,16 +193,16 @@
      * Dialog for report a problem during download.
      * @param errs Primitives involved
-     * @param TITLE Title of dialog
-     * @param TEXT Detail message
-     * @param LIST_LABEL List of primitives description
-     * @param msgType Type of message {@see JOptionPane}
+     * @param title Title of dialog
+     * @param text Detail message
+     * @param listLabel List of primitives description
+     * @param msgType Type of message, see {@link JOptionPane}
      * @return The Dialog object
      */